<?php
/*
Plugin Name: RatingCaptian
Description: Integrate your woocommerce shop with ratingcaptain
Author: mathieu.pl
Version: 2.7
License: GPLv2
Text Domain: rating-captain
*/
require('php-client/RatingCaptain.php');
if(!class_exists('RatingcaptainPlugin')):
    class RatingcaptainPlugin
    {
        /*
        * AutoLoad Hooks
        */
        public function __construct(){
            register_activation_hook(__FILE__, array(&$this, 'ratingcaptain_install'));
            add_action('admin_menu', array(&$this, 'ratingcaptain_options_page'));
            add_action( 'woocommerce_order_status_completed', array(&$this, 'proccess_backend'));

        }

        /*
        * Activation Hook
        */
        public function ratingcaptain_install(){
            $this->ratingcaptain_storeData('', false);
        }
        public function proccess_backend($order_id){
            $order = wc_get_order($order_id);
            if($order instanceof WC_Order){
                $opt = get_option('ratingcaptain_data');
                if($opt && $opt != ''){
                    $options = json_decode($opt);
                    if(isset($options->api_key)){
                        $ratingcaptain = new RatingCaptain($options->api_key);
                        if(isset($options->send_products) && $options->send_products != false){
                            foreach ($order->get_items() as $key_data => $item_data){
                                $product = $item_data->get_product();
                                if($product instanceof WC_Product){
                                    $image_id = $product->get_image_id();
                                    if($image_id){
                                        $image_url = wp_get_attachment_image_url($image_id, 'full');
                                    }else{
                                        $image_url = null;
                                    }
                                    $ratingcaptain->addProduct($product->get_id(), $product->get_name(), $product->get_price(), $image_url, null, $product->get_permalink(), $product->get_sku());
                                }
                            }
                            $res = $ratingcaptain->send(['external_id' => $order->get_order_number(), 'email' => $order->get_billing_email()]);
                        }
                    }
                }
            }
        }
        /*
        * Admin Menu
        */
        public function ratingcaptain_options_page(){
            add_options_page('RatingCaptain Page', 'RatingCaptain Page','manage_options','ratingcaptain_settings',array(&$this, 'ratingcaptain_settings'));
        }

        public function ratingcaptain_storeData($key, $send_products = false){
            add_option('ratingcaptain_data', json_encode(['api_key' => $key, 'send_products' => $send_products]));
        }
        /*
        * Duplicate Page Admin Settings
        */
        public function ratingcaptain_settings(){
            if(current_user_can( 'manage_options' )){
                include('Admin/ratingcaptain_settings.php');
            }
        }
    }
    new RatingcaptainPlugin;
endif;
?>
